@@ -21,7 +21,7 @@ from Qt import QtCore, QtGui, QtWidgets
 from .eventhook import QEventHook
 
 
-event_hook = QEventHook()
+event_hook = QEventHook.instance()
 
 
 class BindingBase(object):
@@ -139,9 +139,6 @@ class NotifyList(list):
         __setslice__ = notify(list.__setslice__)
         __delslice__ = notify(list.__delslice__)
 
-        def __getslice__(self, *args):
-            return self.__class__(list.__getslice__(self, *args))
-
     __delitem__ = notify(list.__delitem__)
 
     def __getitem__(self, item):
@@ -256,8 +253,6 @@ class Binding(QtGui.QStandardItem, BindingBase):
         cls.__trace = False
 
     def __get__(self, instance, owner):
-        self.__class__._inst_ = [self]
-        self._trace_list_.append(self) if self.__trace else None
         return self.get()
 
     def __rrshift__(self, d):
@@ -273,6 +268,8 @@ class Binding(QtGui.QStandardItem, BindingBase):
         self.emit()
 
     def get(self):
+        self.__class__._inst_ = [self]
+        self._trace_list_.append(self) if self.__trace else None
         return self.val
 
     @classmethod
