@@ -21,64 +21,52 @@ import six
 import inspect
 from functools import partial
 
-from Qt import QtCore
-from Qt import QtWidgets
-from Qt import QtGui
+from Qt import QtCore, QtWidgets, QtGui
 
 
 class QEventHook(QtCore.QObject):
 
     __invert_flag = False
     __instance = None
-    __init_flag = False
     __hook = {}
     __invert_hook = {}
     __event = None
     __callbacks = None
 
-    def __new__(cls):
-        if cls.__instance is None:
-            cls.__instance = super(QEventHook, cls).__new__(cls)
-            cls.__init_flag = True
+    @classmethod
+    def instance(cls, *args, **kwargs):
+        if not cls.__instance:
+            cls.__instance = cls(*args, **kwargs)
         return cls.__instance
 
     def __init__(self):
-        if self.__init_flag:
-            self.__init_flag = False
-            super(QEventHook, self).__init__()
-            self.installEventFilter(self)
-            event = QtCore.QEvent(QtCore.QEvent.User)
-            QtCore.QCoreApplication.postEvent(self, event)
+        if self.__instance:
+            raise Exception("This class is a singleton!")
+        super(QEventHook, self).__init__()
+        self.installEventFilter(self)
+        event = QtCore.QEvent(QtCore.QEvent.User)
+        QtCore.QCoreApplication.postEvent(self, event)
 
     def eventFilter(self, receiver, event):
         data = self.__hook.get(receiver)
         if data:
             callbacks = data.get(event.type(), [])
             for callback in callbacks:
-                args = (receiver,)
-                keywords = {}
-                if isinstance(callback, partial):
-                    args = callback.args
-                    keywords = callback.keywords
-                    callback = callback.func
-                    length = len(inspect.getargspec(callback).args)
-                else:
-                    length = len(inspect.getargspec(callback).args)
+                callback = callback.func if isinstance(callback, partial) else callback
+                length = len(inspect.getargspec(callback).args)
                 count = length - 1 if inspect.ismethod(callback) else length
-                args += (event,)
-                callback(*args[:count], **keywords)
+                args = (event,)
+                callback(*args[:count])
 
         # NOTE invert event hook
         data = self.__invert_hook.get(receiver)
         if data is None and type(receiver).__name__ != "QWindow":
             callbacks = self.__invert_hook.get(event.type(), [])
             for callback in callbacks:
+                callback = callback.func if isinstance(callback, partial) else callback
                 length = len(inspect.getargspec(callback).args)
                 count = length - 1 if inspect.ismethod(callback) else length
-                args = (
-                    receiver,
-                    event,
-                )
+                args = (receiver, event)
                 callback(*args[:count])
 
         if receiver is self and event.type() == QtCore.QEvent.User:
